/*
 * bdf2sfd 1.1.5
 * Copyright (c) 2019-2020, Frederic Cambus
 * https://github.com/fcambus/bdf2sfd
 *
 * Created:      2019-11-21
 * Last Updated: 2020-02-08
 *
 * bdf2sfd is released under the BSD 2-Clause license
 * See LICENSE file for details
 */

#ifndef POLYGON_H
#define POLYGON_H

void polygon(uint32_t, uint32_t, uint32_t, float, float, float, float);

#endif /* POLYGON_H */
